@@ -1,6 +1,6 @@
-"""
-Should Include:
-Basic error classes and their descriptors
+"""Includes classes and functions related to errors (and error handling)
+
+Note: Basically every other module in this package (Smg88) depends on this one :) no pressure self
 """
 
 
@@ -10,13 +10,12 @@ class ErrorHandle():
 
     handleName = "Generic Error Handle: "
 
-    @classmethod
-    def __init__(self, msg, *msgs, **extra):
+    def __init__(cls, msg, *msgs, **extra):
         msg = str(msg)
         _msgs = [str(m) for m in msgs]
         _msgs = '\n'.join(_msgs)
-        self.msg = f"{self.handleName}\n{msg}\n{_msgs}"
-        self.extras = extra
+        cls.msg = f"{cls.handleName}\n{msg}\n{_msgs}"
+        cls.extras = extra
 
     def __str__(self):
         return f"{self.msg}"
@@ -53,6 +52,7 @@ class SafeCatchAll(Error, Exception):
     """
     ...
 
+
 class ProgrammerError(Error):
     """Exception class that is root of all internal / implementation / programmer related errors
     """
