@@ -11,7 +11,8 @@ from datetime import datetime
 from enum import Enum, auto, unique
 import logging
 from typing import Callable
-import errors
+
+from . import errors
 
 # Logging levels are as follows:
 # Note that commented definitions are default for the logging module anyway
@@ -117,7 +118,7 @@ class EnumParent(Enum):
 
 
 def now():
-  return datetime.now().strftime("%d/%m/%Y %H:%M:%S")
+    return datetime.now().strftime("%d/%m/%Y %H:%M:%S")
 
 
 def callbacknamed(name: str = ...):
